import QtQuick 2.0
import Sailfish.Silica 1.0
import com.jolla.settings 1.0
import com.jolla.settings.system 1.0
import org.nemomobile.systemsettings 1.0
import org.nemomobile.configuration 1.0

Page {
    id: root
	
    ConfigurationGroup {
        id: topMenuSettings
        path: "/desktop/lipstick-jolla-home/topMenuSettings"
        property bool override_bg_opacity: false
        property real bg_opacity: 70.0
        property bool override_bg_radius: false
        property real bg_radius: 50.0
        property bool btn_wrap_text: false
		property bool restart_homescreen: true
		property bool hide_lock: false
        property int button_mode: 0
        property int ambience_count: 4
		property int shortcuts_count: 4
        property bool hide_cog: false
        property bool hide_handle: false
    }

    ConfigurationGroup {
        id: experimentalFeatures
        path: "/desktop/sailfish/experimental"
        property bool topmenu_shutdown_reboot_visible: false
        property bool topmenu_always_show_lockbutton: false
    }
    ConfigurationValue {
        id: topMenuAmbiencesEnabled

        key: "/desktop/lipstick-jolla-home/topmenu_ambiences_enabled"
        defaultValue: true
    }

    SilicaFlickable {
        anchors.fill: parent
        contentHeight: column.height + Theme.paddingLarge

        VerticalScrollDecorator {}

        Column {
            id: column
            width: parent.width
			
            PageHeader {
                //% "Top menu"
                title: qsTrId("settings_topmenu-he-topmenu")
            }
            ComboBox {
                id: button_mode_combo
                function set_options(i) {
                    topMenuSettings.button_mode = i
                    if (topMenuSettings.button_mode == 0) {
                        experimentalFeatures.topmenu_always_show_lockbutton = false
                        experimentalFeatures.topmenu_shutdown_reboot_visible = false
                        topMenuSettings.hide_lock = false
                    }
                    else if (topMenuSettings.button_mode == 1) {
                        experimentalFeatures.topmenu_always_show_lockbutton = false
                        experimentalFeatures.topmenu_shutdown_reboot_visible = false
                        topMenuSettings.hide_lock = true
                    }
                    else if (topMenuSettings.button_mode == 2) {
                        experimentalFeatures.topmenu_always_show_lockbutton = false
                        experimentalFeatures.topmenu_shutdown_reboot_visible = true
                        topMenuSettings.hide_lock = false
                    }
                    else if (topMenuSettings.button_mode == 3) {
                        experimentalFeatures.topmenu_always_show_lockbutton = true
                        experimentalFeatures.topmenu_shutdown_reboot_visible = false
                        topMenuSettings.hide_lock = false
                    }

                }
                width: parent.width
                label: "Power/Lock Buttons"
                description: "Last two modes each use builtin settings \"/desktop/sailfish/experimental/topmenu_shutdown_reboot_visible\" and \"/desktop/sailfish/experimental/topmenu_always_show_lockbutton\" respectively."
                currentIndex: topMenuSettings.button_mode
                menu: ContextMenu {
                    MenuItem {
                        text: "Default behaviour"
                        onClicked: button_mode_combo.set_options(0)
                    }
                    MenuItem {
                        text: "Hide lock button"
                        onClicked: button_mode_combo.set_options(1)
                    }
                    MenuItem {
                        text: "Always show power buttons"
                        onClicked: button_mode_combo.set_options(2)
                    }
                    MenuItem {
                        text: "Always show power & lock buttons"
                        onClicked: button_mode_combo.set_options(3)
                    }
                }
            }
			TextSwitch {
	            width: parent.width
	            text: qsTr("Show restart homescreen button")
                description: qsTr("Visible along power buttons")
	            checked: topMenuSettings.restart_homescreen
	            onClicked: topMenuSettings.restart_homescreen = checked
	        }

            Slider {
                width: parent.width
                label: qsTr("Toggles/Shortcuts per row")
                maximumValue: 10
                minimumValue: 1
                stepSize: 1
                value: topMenuSettings.shortcuts_count
                valueText: value

                onValueChanged: topMenuSettings.shortcuts_count = value
                onPressAndHold: cancel()
            }

            TextSwitch {
                width: parent.width
                text: qsTr("Wrap button text")
                description: qsTr("May require homescreen restart")
                checked: topMenuSettings.btn_wrap_text
                onClicked: topMenuSettings.btn_wrap_text = checked
            }

			TextSwitch {
	            width: parent.width
	            text: qsTr("Override toggle button background opacity")
	            checked: topMenuSettings.override_bg_opacity
	            onClicked: topMenuSettings.override_bg_opacity = checked
            }
			Slider {
			    width: parent.width
				visible: topMenuSettings.override_bg_opacity
                label: qsTr("Opacity")
                maximumValue: 100
                minimumValue: 0
                stepSize: 1
                value: topMenuSettings.bg_opacity
                valueText: value + "%"

                onValueChanged: topMenuSettings.bg_opacity = value
                onPressAndHold: cancel()
			}
            
            TextSwitch {
	            width: parent.width
	            text: qsTr("Override toggle button background corner radius")
	            checked: topMenuSettings.override_bg_radius
	            onClicked: topMenuSettings.override_bg_radius = checked
	        }
			Slider {
			    width: parent.width
				visible: topMenuSettings.override_bg_radius
                label: qsTr("Corner radius")
                maximumValue: 50
                minimumValue: 0
                stepSize: 1
                value: topMenuSettings.bg_radius
                valueText: value + "%"

                onValueChanged: topMenuSettings.bg_radius = value
                onPressAndHold: cancel()
            }

		    TextSwitch {
	            width: parent.width
	            text: qsTr("Hide Organize button (cog)")
                description: topMenuSettings.hide_cog ? "Disable this if/when you want to organize the icons again" : ""
	            checked: topMenuSettings.hide_cog
	            onClicked: topMenuSettings.hide_cog = checked
	        }

		    TextSwitch {
	            width: parent.width
	            text: qsTr("Hide bottom handle")
	            checked: topMenuSettings.hide_handle
	            onClicked: topMenuSettings.hide_handle = checked
	        }

            IconTextSwitch {
                //: Label in icon text switch which allows the user to enable or disable the ambience selector in the top menu
                //% "Show ambiences in top menu"
                text: qsTrId("settings_topmenu-la-ambiences_switch")

                //: Label containing a description of what the ambience selector is
                //% "Quickly browse and switch between ambiences"
                description: qsTrId("settings_topmenu-la-ambiences_description") + "\n(Same setting as in Settings -> Top Menu)"

                icon.source: "image://theme/icon-m-ambience"
                checked: topMenuAmbiencesEnabled.value
                automaticCheck: false
                onClicked: {
                    topMenuAmbiencesEnabled.value = !topMenuAmbiencesEnabled.value
                }
            }

            Slider {
                width: parent.width
                visible: topMenuAmbiencesEnabled.value
                label: qsTr("Ambience count")
                maximumValue: 10
                minimumValue: 1
                stepSize: 1
                value: topMenuSettings.ambience_count
                valueText: value

                onValueChanged: topMenuSettings.ambience_count = value
                onPressAndHold: cancel()
            }

            PageHeader {
                title: qsTr("About")
            }

            Label {
                width: parent.width
                wrapMode: Text.Wrap
                horizontalAlignment: Text.AlignHCenter
                text: qsTr("Patch created by Okxa.\nThe patch is largely rewritten by necessity, but uses some ideas and basic code from Ancelads old Topmenu Control patch, while dropping some features and adding new ones.\nHomescreen restart icon is from Ancelads patch.")
            }
        }
    }
}
